@@ -1,17 +1,17 @@
+from .ninjax import __version__
+
 # Basics
 from .ninjax import Module
 from .ninjax import Variable
 from .ninjax import pure
-from .ninjax import rng
+from .ninjax import init
+from .ninjax import seed
 
 # Transforms
 from .ninjax import grad
-from .ninjax import jit
-from .ninjax import pmap
-
-# Control Flow
 from .ninjax import cond
 from .ninjax import scan
+from .ninjax import checkpoint
 
 # Advanced
 from .ninjax import context
@@ -19,6 +19,6 @@ from .ninjax import creating
 from .ninjax import scope
 
 # Integrations
-from .ninjax import HaikuModule
-from .ninjax import FlaxModule
-from .ninjax import OptaxModule
+from .ninjax import FromHaiku
+from .ninjax import FromFlax
+from .ninjax import FromOptax
